/*
 * Inspired by MsaRowTitleComponent.tsx
 * https://github.com/rcsb/rcsb-saguaro-3d/blob/c44fae65cb3b201c3d758ee15509b9fdbd3bd0a6/src/RcsbFvSequence/SequenceViews/RcsbView/PfvManagerFactoryImplementation/MsaPfvComponents/MsaRowTitleComponent.tsx
 *
 * Further rendering info can be accessed here:
 * https://github.com/rcsb/rcsb-saguaro/blob/master/src/RcsbFv/RcsbFvRow/RcsbFvRowTitle.tsx
 */

import * as React from "react";
import {RcsbFvRowConfigInterface} from "@rcsb/rcsb-saguaro";
import { RcsbFvRowTitleInterface } from "@rcsb/rcsb-saguaro/build/RcsbFv/RcsbFvRow/RcsbFvRowTitle";

interface TmRowTitleInterface extends RcsbFvRowTitleInterface {
    color?: string;
    titleClick?: (e: React.MouseEvent) => void;
}

interface TmRowTitleState {
}

export class TmRowTitleComponent extends React.Component<TmRowTitleInterface, TmRowTitleState> {

    private readonly configData : RcsbFvRowConfigInterface;

    readonly state = {
        url: undefined
    };

    constructor(props: TmRowTitleInterface) {
        super(props);
        this.configData = this.props.data;

        if ((this.configData.externalRowTitle?.rowTitleAdditionalProps
            && (this.configData.externalRowTitle?.rowTitleAdditionalProps as any).url)) {

            this.state.url = (this.configData.externalRowTitle?.rowTitleAdditionalProps as any).url;
        }
    }

    public render(): JSX.Element{
        const titleNode = this.state.url
            ? <>
                <a href={this.state.url}
                   style= {{ color: "inherit", textDecorationLine: "none" }}
                >
                    { this.configData.rowTitle as string }
                </a>
            </>
            : <>{ this.configData.rowTitle as string }</>;
       return (
           <div style={{textAlign:"right", display:"flex"}}>
               <div>
                   <div style={{
                           MozUserSelect:"none",
                           WebkitUserSelect:"none",
                           msUserSelect:"none",
                           color: this.props.color ?? "rgb(94, 148, 195)",
                           fontWeight: "bold",
                           cursor: "pointer",
                           maxWidth: (this.configData.rowTitleWidth ?? 190) - 60,
                           overflow: "hidden",
                           textOverflow: "ellipsis",
                           whiteSpace: "nowrap",
                           textAlign: "right"
                       }}
                       onClick={ (e: React.MouseEvent) => this.click(e) }
                   >
                       { titleNode }
                   </div>
               </div>
           </div>
       );
    }

    protected click(e: React.MouseEvent) {
        if (!this.props.titleClick) {
            console.warn('title click handler is not set:', e);
        } else {
            this.props.titleClick!(e);
        }
    }
}
